sigal - yet another simple static gallery generator
===================================================

.. image:: https://secure.travis-ci.org/saimn/sigal.png?branch=master
   :target: https://travis-ci.org/saimn/sigal
   :alt: Travis-ci: continuous integration status.

Sigal is yet another simple static gallery generator. It's written in Python
and it allows to build a static gallery of images with the following features:

* process directories recursively,
* resize images and create thumbnails,
* generate html pages using jinja2 templates,
* relative links for a portable output,
* MIT licensed.

Links :

* Latest documentation on the `website`_
* Source, issues and pull requests on `Github`_
* Releases on `PyPI`_

.. _website: http://sigal.saimon.org/
.. _Github: https://github.com/saimn/sigal/
.. _PyPI: http://pypi.python.org/pypi/sigal
